program pdfindex;

{$mode objfpc}
{$h+}

uses custapp, cwString, sysutils, classes, contnrs, fppdfindexer, inifiles, sqldbini, fppdf;


Type

  { TPDFIndexerApplication }

  TPDFIndexerApplication = class(TCustomApplication)
    Procedure Configure(const aFileName : String;aIdx : TPDFIndexer);
    Procedure DoRun; override;
  private
    procedure Usage(const aError: String);
  end;

procedure TPDFIndexerApplication.Usage(const aError: String);

begin
  GetLocalTimeOffset;
  if aError<>'' then
    Writeln('Error : ',aError);
  Writeln('Usage: ',ExeName,' -h -c config [-d|-i file1 [file2 ...]]');
  Writeln('Where ');
  Writeln('-h --help          This help text');
  Writeln('-c --config=FILE   Database configuration file');
  Writeln('-i --index         Index files');
  Writeln('-t --create-tables Create database tables');
  ExitCode:=Ord(aError<>'');
end;

procedure TPDFIndexerApplication.Configure(const aFileName: String;
  aIdx: TPDFIndexer);

Const
  SSection = 'Database';
  KeyHost = 'Host';
  KeyDatabaseName = 'DatabaseName';
  KeyUserName = 'UserName';
  KeyPassword = 'Password';
{  KeyPort = 'Port';
  keyParams = 'Params';
  KeyCharset = 'Charset';
  KeyRole = 'Role';}

var
  aIni : TCustomIniFile;

begin
  if (aFileName='') then
    begin
    Usage('Need a database configuration');
    exit;
    end;
  aIni:=TMemIniFile.Create(aFileName);
  try
    With aIdx.Indexer do
      begin
      HostName:=aIni.ReadString(SSection,KeyHost,HostName);
      DatabasePath:=aIni.ReadString(SSection,KeyDatabaseName,DatabasePath);
      UserName:=aIni.ReadString(SSection,KeyUserName,UserName);
      Password:=aIni.ReadString(SSection,KeyPassword,Password);
      end;
  finally
    aIni.Free;
  end;
end;

procedure TPDFIndexerApplication.DoRun;

Const
  Short = 'c:dih';
  Long : array of string = ('config:','database','index','help');

var
  Idx : TPDFIndexer;
  aFile,Msg : String;
  Files : Array of string;

begin
  StopOnException:=True;
  Terminate;
  Msg:=CheckOptions(Short,Long);
  if (Msg<>'') or HasOption('h','help') then
    begin
    Usage(Msg);
    exit;
    end;
  Files:=GetNonOptions(Short,Long);
  Idx:=TPDFIndexer.Create(Self);
  try
    Configure(GetOPtionValue('c','config'),Idx);
    if HasOption('i','index') then
      begin
      Files:=GetNonOptions(Short,Long);
      if Length(Files)=0 then
        begin
        Usage('No files specified');
        exit;
        end;
      For aFile in Files do
        begin
        Writeln('Indexing ',aFile);
        Idx.IndexPDF(aFile);
        end;
      end
    else if HasOption('t','create-tables') then
      Idx.CreateTables
    else
      Usage('One of -i or -t must be specified');
  finally
    Idx.Free;
  end;
end;

begin
  With TPDFIndexerApplication.Create(Nil) do
   try
     Initialize;
     Run;
   Finally
     Free;
   end;
end.

